@@ -4,6 +4,8 @@
 #include <QDialog>
 #include <QSettings>
 #include <QModelIndex>
+#include <QInputDialog>
+#include "edit.h"
 
 
 namespace Ui {
@@ -24,9 +26,13 @@ private:
     QSettings mvSettings;
     QString mvCurrency1;
     QString mvCurrency2;
+    Edit *editDialog;
 
+    void displayRate();
+    void updateList();
 
 private slots:
+    void on_pushButton_Edit_clicked();
     void on_pushButton_Apply_clicked();
     void on_listWidget2_clicked(QModelIndex index);
     void on_listWidget1_clicked(QModelIndex index);
