@@ -38,43 +38,80 @@ void MainWindow::changeEvent(QEvent *e)
 
 void MainWindow::initialSettings()
 {
-    if (!mvSettings.contains("Currency1")) {
+     if (mvSettings.value("Restore").toInt() < 1) {
+        mvSettings.setValue("Restore", 1);
         mvSettings.setValue("Currency1", "EUR");
         mvSettings.setValue("Currency2", "USD");
         mvSettings.setValue("TaxRate", 20);
         mvSettings.setValue("TipRate", 10);
-        mvSettings.setValue("USD", 1.4374);
-        mvSettings.setValue("JPY", 130.76);
-        mvSettings.setValue("BGN", 1.9558);
-        mvSettings.setValue("CZK", 25.947);
-        mvSettings.setValue("DKK", 7.4420);
-        mvSettings.setValue("EEK", 15.6466);
-        mvSettings.setValue("GBP", 0.88105);
-        mvSettings.setValue("HUF", 266.80);
-        mvSettings.setValue("LTL", 3.4528);
-        mvSettings.setValue("LVL", 0.7085);
-        mvSettings.setValue("PLN", 4.0399);
-        mvSettings.setValue("RON", 4.1043);
-        mvSettings.setValue("SEK", 10.1430);
-        mvSettings.setValue("CHF", 1.4756);
-        mvSettings.setValue("NOK", 8.1430);
-        mvSettings.setValue("HRK", 7.2890);
-        mvSettings.setValue("RUB", 42.5015);
-        mvSettings.setValue("TRY", 2.0900);
-        mvSettings.setValue("AUD", 1.5547);
-        mvSettings.setValue("BRL", 2.5438);
-        mvSettings.setValue("CAD", 1.4752);
-        mvSettings.setValue("CNY", 9.8130);
-        mvSettings.setValue("HKD", 11.1536);
-        mvSettings.setValue("IDR", 65.7000);
-        mvSettings.setValue("KRW", 1614.29);
-        mvSettings.setValue("MXN", 18.2790);
-        mvSettings.setValue("MYR", 4.8002);
-        mvSettings.setValue("NZD", 1.9497);
-        mvSettings.setValue("PHP", 65.867);
-        mvSettings.setValue("SGD", 1.9984);
-        mvSettings.setValue("THB", 47.244);
-        mvSettings.setValue("ZAR", 10.6588);
+        mvSettings.setValue("Currency/EUR", 1);
+        mvSettings.setValue("Currency/USD", 1.4374);
+        mvSettings.setValue("Currency/JPY", 130.76);
+        mvSettings.setValue("Currency/BGN", 1.9558);
+        mvSettings.setValue("Currency/CZK", 25.947);
+        mvSettings.setValue("Currency/DKK", 7.4420);
+        mvSettings.setValue("Currency/EEK", 15.6466);
+        mvSettings.setValue("Currency/GBP", 0.88105);
+        mvSettings.setValue("Currency/HUF", 266.80);
+        mvSettings.setValue("Currency/LTL", 3.4528);
+        mvSettings.setValue("Currency/LVL", 0.7085);
+        mvSettings.setValue("Currency/PLN", 4.0399);
+        mvSettings.setValue("Currency/RON", 4.1043);
+        mvSettings.setValue("Currency/SEK", 10.1430);
+        mvSettings.setValue("Currency/CHF", 1.4756);
+        mvSettings.setValue("Currency/NOK", 8.1430);
+        mvSettings.setValue("Currency/HRK", 7.2890);
+        mvSettings.setValue("Currency/RUB", 42.5015);
+        mvSettings.setValue("Currency/TRY", 2.0900);
+        mvSettings.setValue("Currency/AUD", 1.5547);
+        mvSettings.setValue("Currency/BRL", 2.5438);
+        mvSettings.setValue("Currency/CAD", 1.4752);
+        mvSettings.setValue("Currency/CNY", 9.8130);
+        mvSettings.setValue("Currency/HKD", 11.1536);
+        mvSettings.setValue("Currency/IDR", 13245.61);
+        mvSettings.setValue("Currency/INR", 65.7000);
+        mvSettings.setValue("Currency/KRW", 1614.29);
+        mvSettings.setValue("Currency/MXN", 18.2790);
+        mvSettings.setValue("Currency/MYR", 4.8002);
+        mvSettings.setValue("Currency/NZD", 1.9497);
+        mvSettings.setValue("Currency/PHP", 65.867);
+        mvSettings.setValue("Currency/SGD", 1.9984);
+        mvSettings.setValue("Currency/THB", 47.244);
+        mvSettings.setValue("Currency/ZAR", 10.6588);
+        mvSettings.setValue("CurrencyName/EUR", "Euro");
+        mvSettings.setValue("CurrencyName/USD", "US dollar");
+        mvSettings.setValue("CurrencyName/JPY", "Japanese yen");
+        mvSettings.setValue("CurrencyName/BGN", "Bulgarian lev");
+        mvSettings.setValue("CurrencyName/CZK", "Czech koruna");
+        mvSettings.setValue("CurrencyName/DKK", "Danish krone");
+        mvSettings.setValue("CurrencyName/EEK", "Estonian kroon");
+        mvSettings.setValue("CurrencyName/GBP", "Pound sterling");
+        mvSettings.setValue("CurrencyName/HUF", "Hungarian forint");
+        mvSettings.setValue("CurrencyName/LTL", "Lithuanian litas");
+        mvSettings.setValue("CurrencyName/LVL", "Latvian lats");
+        mvSettings.setValue("CurrencyName/PLN", "Polish zloty");
+        mvSettings.setValue("CurrencyName/RON", "Romanian leu");
+        mvSettings.setValue("CurrencyName/SEK", "Swedish krona");
+        mvSettings.setValue("CurrencyName/CHF", "Swiss franc");
+        mvSettings.setValue("CurrencyName/NOK", "Norwegian krone");
+        mvSettings.setValue("CurrencyName/HRK", "Croatian kuna");
+        mvSettings.setValue("CurrencyName/RUB", "Russian rouble");
+        mvSettings.setValue("CurrencyName/TRY", "Turkish lira");
+        mvSettings.setValue("CurrencyName/AUD", "Australian dollar");
+        mvSettings.setValue("CurrencyName/BRL", "Brasilian real");
+        mvSettings.setValue("CurrencyName/CAD", "Canadian dollar");
+        mvSettings.setValue("CurrencyName/CNY", "Chinese yuan renminbi");
+        mvSettings.setValue("CurrencyName/HKD", "Hong Kong dollar");
+        mvSettings.setValue("CurrencyName/IDR", "Indonesian rupiah");
+        mvSettings.setValue("CurrencyName/INR", "Indian rupee");
+        mvSettings.setValue("CurrencyName/KRW", "South Korean won");
+        mvSettings.setValue("CurrencyName/MXN", "Mexican peso");
+        mvSettings.setValue("CurrencyName/MYR", "Malaysian ringgit");
+        mvSettings.setValue("CurrencyName/NZD", "New Zealand dollar");
+        mvSettings.setValue("CurrencyName/PHP", "Philippine peso");
+        mvSettings.setValue("CurrencyName/SGD", "Singapore dollar");
+        mvSettings.setValue("CurrencyName/THB", "Thai baht");
+        mvSettings.setValue("CurrencyName/ZAR", "South African rand");
     }
 
 }
@@ -206,14 +243,14 @@ void MainWindow::convertCurrency(QString fromCurrency, QString toCurrency)
     if (fromCurrency == "EUR") {
         fromEuro = true;
     } else {
-        fromRate = mvSettings.value(fromCurrency).toDouble();
+        fromRate = mvSettings.value("Currency/" + fromCurrency).toDouble();
         fromEuro = false;
     }
 
     if (toCurrency == "EUR") {
         toEuro = true;
     } else {
-        toRate = mvSettings.value(toCurrency).toDouble();
+        toRate = mvSettings.value("Currency/" + toCurrency).toDouble();
         toEuro = false;
     }
 
@@ -265,13 +302,15 @@ void MainWindow::updateCurrency()
                     mvSettings.setValue("CurrencyTime", currencyTime.toString());
                 }
                 if (!currencyName.isEmpty()) {
-                    mvSettings.setValue(currencyName.toString(), currencyRate.toString());
+                    mvSettings.setValue("Currency/" + currencyName.toString(), currencyRate.toString());
                 }
             }
         }
         xml.readNext();
     }
     
+    mvSettings.setValue("Currency/EUR", 1);
+
     QDate date = mvSettings.value("CurrencyTime").toDate();
     QString updated = date.toString();
 
